@@ -186,10 +186,20 @@ void command_reload(gpointer callback_data,guint callback_action,
 			g_free(ptw->start);
 			ptw->start=p;
 		}
-		/* ɤ߹ */
-		open_text_file(ptw);
 		delete_list(&ptw->undo);
 		delete_list(&ptw->redo);
+		/* ɤ߹ */
+		open_text_file(ptw);
+		if (ptw->start==NULL) {
+			/* ե뤬0ХȤΤȤ */
+			ptw->off=0;
+			ptw->max=1;
+			ptw->start=g_malloc(sizeof(LINEBUF));
+			ptw->start->length=0;
+			ptw->start->margin=FALSE;
+			ptw->start->text=NULL;
+			ptw->start->prev=ptw->start->next=NULL;
+		}
 		ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
 		ptw->edit=FALSE;
 		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
