@@ -18,6 +18,7 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "conf.h"
+#include "other.h"
 
 
 /******************************************************************************
@@ -26,7 +27,7 @@
 *                                                                             *
 ******************************************************************************/
 static gint width,height;
-static GtkWidget *button0,*check,*spin0,*spin1,*spin2;
+static GtkWidget *button0,*check0,*check1,*spin0,*spin1,*spin2;
 
 
 /* OKܥɽ */
@@ -51,7 +52,8 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 	GtkWidget *sub_menu;
 
 	history=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
-	newfile=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
+	newfile=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
+	second=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check1));
 	def_width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
 	def_height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
 	gtk_widget_destroy(dialog);
@@ -91,7 +93,9 @@ static gboolean conf_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 
 void conf_dialog(void)
 {
-	GtkWidget *dialog,*button1,*frame,*hbox0,*hbox1,*vbox;
+	GtkAccelGroup *accel;
+	GtkWidget *dialog,*button1,*label0,*label1,*label2;
+	GtkWidget *frame,*hbox0,*hbox1,*vbox;
 
 	width=gdk_screen_width();
 	height=gdk_screen_height();
@@ -112,9 +116,12 @@ void conf_dialog(void)
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check=gtk_check_button_new_with_label(_("ե򳫤"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),newfile);
-	gtk_signal_connect(GTK_OBJECT(check),"toggled",conf_dialog_toggled,NULL);
+	check0=gtk_check_button_new_with_label(_("ե򳫤"));
+	check1=gtk_check_button_new_with_label(_("ɥ򳫤"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),newfile);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),second);
+	gtk_signal_connect(GTK_OBJECT(check0),"toggled",conf_dialog_toggled,NULL);
+	gtk_signal_connect(GTK_OBJECT(check1),"toggled",conf_dialog_toggled,NULL);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(
 			GTK_ADJUSTMENT(gtk_adjustment_new(history,0,10,1,5,0)),0,0);
@@ -137,16 +144,43 @@ void conf_dialog(void)
 	gtk_signal_connect(GTK_OBJECT(spin0),"changed",conf_dialog_changed,NULL);
 	gtk_signal_connect(GTK_OBJECT(spin1),"changed",conf_dialog_changed,NULL);
 	gtk_signal_connect(GTK_OBJECT(spin2),"changed",conf_dialog_changed,NULL);
+	/* ٥ */
+	label0=gtk_label_new(_("ե"));
+	label1=gtk_label_new(_(""));
+	label2=gtk_label_new(_("⤵"));
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_widget_add_accelerator(spin0,"grab-focus",accel,'I',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(label0,'I');
+	gtk_widget_add_accelerator(check0,"clicked",accel,'N',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check0)->child,'N');
+	gtk_widget_add_accelerator(check1,"clicked",accel,'O',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check1)->child,'O');
+	gtk_widget_add_accelerator(spin1,"grab-focus",accel,'W',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(label1,'W');
+	gtk_widget_add_accelerator(spin2,"grab-focus",accel,'H',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(label2,'H');
 	/* ե졼ȥܥå */
 	frame=gtk_frame_new(_("ɥΥ"));
 	vbox=gtk_vbox_new(FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,0);
 	hbox1=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox1),gtk_label_new(_("")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox1),label1,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
 	hbox1=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox1),gtk_label_new(_("⤵")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox1),label2,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin2,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
@@ -155,13 +189,15 @@ void conf_dialog(void)
 	vbox=gtk_vbox_new(FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,0);
 	hbox1=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox1),
-							gtk_label_new(_("ե")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox1),label0,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin0,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
 	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),check,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),check0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	hbox0=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),check1,FALSE,FALSE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
 	hbox0=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),frame,FALSE,FALSE,8);
