@@ -277,7 +277,7 @@ TEXTWND *open_edit_file(gchar *file)
 		ptw->fontname=g_strdup(ftype[0].fontname);
 		memcpy(ptw->color,ftype[0].color,sizeof(GdkColor)*12);
 	} else {
-		ptw->file=g_strdup(file);
+		ptw->file=get_full_path(file);
 		leng0=strlen(ptw->file);
 		for (i=0;i<ftnum;i++) {
 			if (strcmp(ftype[i].ext,"*")==0)
@@ -398,8 +398,8 @@ TEXTWND *open_edit_file(gchar *file)
 	gtk_widget_grab_focus(ptw->drawing);
 
 	/* ǤϤʤե뤬¸ߤˤ˲ä */
-	if (file!=NULL && history>0 && isfile(file))
-		set_history(file);
+	if (file!=NULL && history>0 && isfile(ptw->file))
+		set_history(ptw->file);
 
 	return ptw;
 }
