@@ -20,6 +20,7 @@
 #include <gdk/gdkkeysyms.h>
 #include "format.h"
 #include "general.h"
+#include "other.h"
 #include "prop.h"
 
 
@@ -145,6 +146,7 @@ static gboolean format_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 void format_dialog(void)
 {
 	gint i;
+	GtkAccelGroup *accel;
 	GtkWidget *dialog,*button5,*clist,*scroll,*hbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
@@ -198,6 +200,29 @@ void format_dialog(void)
 	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button5,GTK_CAN_DEFAULT);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_widget_add_accelerator(button0,"clicked",accel,'N',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button0)->child,'N');
+	gtk_widget_add_accelerator(button1,"clicked",accel,'R',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button1)->child,'R');
+	gtk_widget_add_accelerator(button2,"clicked",accel,'U',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button2)->child,'U');
+	gtk_widget_add_accelerator(button3,"clicked",accel,'D',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button3)->child,'D');
+	gtk_widget_add_accelerator(button4,"clicked",accel,'E',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button4)->child,'E');
 	/* ܥå */
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
