@@ -16,6 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
+#include <ctype.h>
 #include "command.h"
 #include "edit.h"
 #include "find.h"
@@ -97,7 +98,7 @@ void draw_caret(TEXTWND *ptw,GdkPoint *cursor)
 	g_free(text);
 #ifdef USE_XIM
 	if (GTK_WIDGET_HAS_FOCUS(ptw->drawing) && gdk_im_ready() && ptw->ic!=NULL
-					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
+				&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
 		ptw->ic_attr->spot_location.x=rc.x;
 		ptw->ic_attr->spot_location.y=rc.y+ptw->fontascent;
 		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_SPOT_LOCATION);
@@ -127,7 +128,8 @@ void set_menu_bar(TEXTWND *ptw)
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/̾Ĥ¸(A)...")),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/¸Ƥ֤᤹(R)...")),TRUE);
+				_("<main>/ե(F)/¸Ƥ֤᤹(R)...")),
+																!ptw->create);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 				_("<main>/ե(F)/ץѥƥ(I)...")),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
@@ -299,11 +301,11 @@ DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
 		gtk_widget_draw(ptw->drawing,&rc);
 		/* äԿʬ */
 		scroll_window(ptw->drawing,0,-delete*ptw->fontsize*2,
-							0,
-							(ptw->cursor.y-ptw->top.y+1)*ptw->fontsize*2,
-							ptw->drawing->allocation.width,
-							ptw->drawing->allocation.height
-								-(ptw->cursor.y-ptw->top.y+1)*ptw->fontsize*2);
+						0,
+						(ptw->cursor.y-ptw->top.y+1)*ptw->fontsize*2,
+						ptw->drawing->allocation.width,
+						MAX(ptw->drawing->allocation.height
+							-(ptw->cursor.y-ptw->top.y+1)*ptw->fontsize*2,0));
 		/* 򽪤֤鱦ޡαƶΤԿ */
 		for (i=0,p=get_line_buf(&ptw->start,&ptw->off,ptw->cursor.y);
 														p!=NULL;i++,p=p->next)
@@ -348,11 +350,11 @@ DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
 		gtk_widget_draw(ptw->drawing,&rc);
 		/* Կʬ */
 		scroll_window(ptw->drawing,0,put*ptw->fontsize*2,
-							0,
-							(cursor_old.y-ptw->top.y+1)*ptw->fontsize*2,
-							ptw->drawing->allocation.width,
-							ptw->drawing->allocation.height
-								-(cursor_old.y-ptw->top.y+1)*ptw->fontsize*2);
+						0,
+						(cursor_old.y-ptw->top.y+1)*ptw->fontsize*2,
+						ptw->drawing->allocation.width,
+						MAX(ptw->drawing->allocation.height
+							-(cursor_old.y-ptw->top.y+1)*ptw->fontsize*2,0));
 		/* 򽪤֤鱦ޡαƶΤԿ */
 		p=q=get_line_buf(&ptw->start,&ptw->off,cursor_new.y);
 		for (i=cursor_new.y,j=0;
@@ -572,7 +574,9 @@ void change_property(TEXTWND *ptw,FTYPE *ft)
 	draw_caret(ptw,NULL);
 #ifdef USE_XIM
 	if (gdk_im_ready() && ptw->ic!=NULL
-					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
+				&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
+		gdk_ic_get_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FONTSET
+					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
 		ptw->ic_attr->preedit_foreground=ptw->syscol
 												?system_color[0]:ptw->color[0];
 		ptw->ic_attr->preedit_background=ptw->syscol
