@@ -17,6 +17,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
+#include "edit.h"
+#include "general.h"
 #include "jump.h"
 #include "other.h"
 
@@ -26,6 +28,53 @@
 * ״ؿ                                                              *
 *                                                                             *
 ******************************************************************************/
+/*	Ԥذư
+	 ptw,TXTɥ
+	line,(1...)														*/
+void jump_operation(TEXTWND *ptw,gint line)
+{
+	gint sx,sy;
+	GdkPoint cursor,select,top;
+
+	cursor=ptw->cursor;
+	select=ptw->select;
+	top=ptw->top;
+	sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
+	sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
+	ptw->cursor.y=line<0?ptw->max+line:line-1;
+	if (ptw->cursor.y<0)
+		ptw->cursor.y=0;
+	else if (ptw->cursor.y>ptw->max-1)
+		ptw->cursor.y=ptw->max-1;
+	if (ptw->cursor.x<ptw->top.x)
+		ptw->top.x=ptw->cursor.x;
+	else if (ptw->cursor.x-sx+1>ptw->top.x)
+		ptw->top.x=ptw->cursor.x-sx+1;
+	if (ptw->cursor.y<ptw->top.y)
+		ptw->top.y=ptw->cursor.y;
+	else if (ptw->cursor.y-sy+1>ptw->top.y)
+		ptw->top.y=ptw->cursor.y-sy+1;
+	move_text_window(ptw,&top);
+	if (ptw->select.x>=0) {
+		if (ptw->select.y==ptw->cursor.y
+						&& ptw->select.x==get_align_pos(&ptw->start,&ptw->off,
+								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE)) {
+			ptw->select.x=-1;
+			clear_sel(ptw,&select,&cursor);
+			set_menu_bar(ptw);
+		} else {
+			clear_sel(ptw,&ptw->cursor,&cursor);
+		}
+	}
+	draw_caret(ptw,&cursor);
+}
+
+
+/******************************************************************************
+*                                                                             *
+* ץؿ                                                    *
+*                                                                             *
+******************************************************************************/
 static gboolean jump_clicked_ok;
 static GtkWidget *dialog,*button0,*entry;
 
