@@ -18,6 +18,7 @@
 */
 #include <ctype.h>
 #include <stdio.h>
+#include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include "other.h"
 
@@ -118,6 +119,83 @@ gboolean isfile(gchar *file)
 }
 
 
+/*	եΥեѥ
+	file,ե̾
+	 RET,եѥ															*/
+gchar *get_full_path(gchar *file)
+{
+	gchar *dir,*path;
+	gint i,j,leng;
+
+	if (file[0]!='/') {
+		dir=g_get_current_dir();
+		path=g_strjoin("/",dir,file,NULL);
+		g_free(dir);
+	} else {
+		path=g_strdup(file);
+	}
+	leng=strlen(path);
+	i=0;
+	while (i<leng)
+		if (path[i]=='/' && path[i+1]=='.' && path[i+2]=='/') {
+			leng-=2;
+			memmove(path+i+1,path+i+3,leng-i);
+		} else {
+			i++;
+		}
+	i=0;
+	while (i<leng)
+		if (path[i]=='/' && path[i+1]=='.' && path[i+2]=='.'
+														&& path[i+3]=='/') {
+			leng-=3;
+			memmove(path+i+1,path+i+4,leng-i);
+			for (j=i-1;j>=0;j--)
+				if (path[j]=='/')
+					break;
+			if (j>=0) {
+				memmove(path+j+1,path+i+1,leng-i);
+				leng-=i-j;
+				i=j;
+			}
+		} else {
+			i++;
+		}
+	return path;
+}
+
+
+/*	٥ʸ˲Ĥ
+	label,٥
+	  key,ʸ																*/
+void set_label_pattern(GtkWidget *label,gchar key)
+{
+	gchar *text,*pattern;
+	gint i;
+
+	gtk_label_get(GTK_LABEL(label),&text);
+	for (i=0;text[i]!='\0';i++)
+		if (toupper(text[i])==toupper(key))
+			break;
+	if (text[i]=='\0') {
+		text=g_strdup_printf("%s(%c)",text,key);
+		gtk_label_set_text(GTK_LABEL(label),text);
+		g_free(text);
+		gtk_label_get(GTK_LABEL(label),&text);
+	}
+	for (i=0;*text!='\0';i++)
+		if (iskanji(*text))
+			text+=2;
+		else if (toupper(*text)!=toupper(key))
+			text++;
+		else
+			break;
+	pattern=g_strnfill(i+1,' ');
+	pattern[i]='_';
+	gtk_label_set_pattern(GTK_LABEL(label),pattern);
+	g_free(pattern);
+}
+
+
 /*	Сꤹ
 	   scroll,륦å
 	     func,ʥؿ
