@@ -18,6 +18,7 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "ftype.h"
+#include "other.h"
 #include "prop.h"
 
 
@@ -297,6 +298,7 @@ gboolean property_dialog(FTYPE *ft)
 	gint i;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
+	GtkAccelGroup *accel;
 	GtkWidget *button1,*button2,*button4,*scroll;
 	GtkWidget *hbox,*tbox,*vbox;
 	GtkWidget *frame0,*frame1,*frame2,*frame3,*frame4;
@@ -453,7 +455,73 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(spin1),"changed",
 											property_dialog_ok_sensitive,NULL);
-
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_widget_add_accelerator(button0,"clicked",accel,'P',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button0)->child,'P');
+	gtk_widget_add_accelerator(button1,"clicked",accel,'F',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button1)->child,'F');
+	if (button2!=NULL) {
+		gtk_widget_add_accelerator(button2,"clicked",accel,'A',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+		set_label_pattern(GTK_BIN(button2)->child,'A');
+	}
+	gtk_widget_add_accelerator(check0,"clicked",accel,'G',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check0)->child,'G');
+	gtk_widget_add_accelerator(check1,"clicked",accel,'S',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check1)->child,'S');
+	gtk_widget_add_accelerator(check2,"clicked",accel,'E',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check2)->child,'E');
+	gtk_widget_add_accelerator(check3,"clicked",accel,'M',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check3)->child,'M');
+	gtk_widget_add_accelerator(check4,"clicked",accel,'I',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check4)->child,'I');
+	gtk_widget_add_accelerator(check5,"clicked",accel,'C',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check5)->child,'C');
+	gtk_widget_add_accelerator(check6,"clicked",accel,'U',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check6)->child,'U');
+	gtk_widget_add_accelerator(check7,"clicked",accel,'V',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check7)->child,'V');
+	gtk_widget_add_accelerator(check8,"clicked",accel,'Z',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check8)->child,'Z');
+	gtk_widget_add_accelerator(check9,"clicked",accel,'O',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check9)->child,'O');
+	gtk_widget_add_accelerator(check10,"clicked",accel,'Y',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check10)->child,'Y');
+	if (check11!=NULL) {
+		gtk_widget_add_accelerator(check11,"clicked",accel,'A',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+		set_label_pattern(GTK_BIN(check11)->child,'A');
+	}
 	/* ե졼ȥܥå */
 	tbox=gtk_hbox_new(FALSE,0);
 	if (entry0!=NULL && entry1!=NULL) {
