@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
+#include "other.h"
 #include "repinfo.h"
 
 
@@ -50,6 +51,7 @@ static gboolean repinfo_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 gint repinfo_dialog(REPINFO *ri)
 {
 	gchar *text;
+	GtkAccelGroup *accel;
 	GtkWidget *button0,*button1,*button2,*button3;
 	GtkWidget *frame0,*frame1,*hbox,*tbox,*vbox;
 
@@ -76,6 +78,21 @@ gint repinfo_dialog(REPINFO *ri)
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_widget_add_accelerator(button0,"clicked",accel,'R',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button0)->child,'R');
+	gtk_widget_add_accelerator(button1,"clicked",accel,'N',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button1)->child,'N');
+	gtk_widget_add_accelerator(button2,"clicked",accel,'A',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button2)->child,'A');
 	/* ե졼ȥܥå */
 	tbox=gtk_vbox_new(FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
