@@ -18,6 +18,7 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "find.h"
+#include "other.h"
 #include "replace.h"
 
 
@@ -93,6 +94,7 @@ gint replace_dialog(REPLACE *rp)
 	gint i;
 	GList *glist=NULL;
 	GSList *group=NULL;
+	GtkAccelGroup *accel;
 	GtkWidget *radio0,*button2;
 	GtkWidget *frame0,*frame1,*hbox,*tbox,*vbox;
 
@@ -150,6 +152,29 @@ gint replace_dialog(REPLACE *rp)
 	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio1));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rp->arrow?radio1:radio0),
 																		TRUE);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_widget_add_accelerator(check,"clicked",accel,'C',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(check)->child,'C');
+	gtk_widget_add_accelerator(radio0,"clicked",accel,'U',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(radio0)->child,'U');
+	gtk_widget_add_accelerator(radio1,"clicked",accel,'D',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(radio1)->child,'D');
+	gtk_widget_add_accelerator(button0,"clicked",accel,'R',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button0)->child,'R');
+	gtk_widget_add_accelerator(button1,"clicked",accel,'A',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(button1)->child,'A');
 	/* ե졼ȥܥå */
 	tbox=gtk_vbox_new(FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
