@@ -21,6 +21,7 @@
 #include "edit.h"
 #include "file.h"
 #include "general.h"
+#include "jump.h"
 #include "other.h"
 #include "signal.h"
 
@@ -81,7 +82,8 @@ void signal_realize(GtkWidget *widget,TEXTWND *ptw)
 	if (gdk_im_ready() && (ptw->ic_attr=gdk_ic_attr_new())!=NULL) {
 		gint width, height;
 		GdkColormap *colormap;
-		GdkICAttributesType attrmask=GDK_IC_ALL_REQ;
+		GdkICAttributesType attrmask=GDK_IC_ALL_REQ
+					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND;
 		GdkIMStyle supported_style=GDK_IM_PREEDIT_NONE
 									| GDK_IM_PREEDIT_NOTHING
 									| GDK_IM_STATUS_NONE
@@ -96,6 +98,10 @@ void signal_realize(GtkWidget *widget,TEXTWND *ptw)
 			attrmask|=GDK_IC_PREEDIT_COLORMAP;
 			ptw->ic_attr->preedit_colormap=colormap;
 		}
+		ptw->ic_attr->preedit_foreground=ptw->syscol
+												?system_color[0]:ptw->color[0];
+		ptw->ic_attr->preedit_background=ptw->syscol
+												?system_color[1]:ptw->color[1];
 		switch (ptw->ic_attr->style&GDK_IM_PREEDIT_MASK) {
 			case GDK_IM_PREEDIT_POSITION:
 				if (ptw->font->type==GDK_FONT_FONTSET) {
@@ -116,12 +122,6 @@ void signal_realize(GtkWidget *widget,TEXTWND *ptw)
 			if (GTK_WIDGET_HAS_FOCUS(ptw->drawing))
 				gdk_im_begin(ptw->ic,ptw->drawing->window);
 		}
-		ptw->ic_attr->preedit_foreground=ptw->syscol
-												?system_color[0]:ptw->color[0];
-		ptw->ic_attr->preedit_background=ptw->syscol
-												?system_color[1]:ptw->color[1];
-		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,
-						GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
 	}
 #endif
 }
@@ -1089,7 +1089,9 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 	default:
 		loop:
 		if (event->string!=NULL
-				&& ((guchar)event->string[0]>=' ' || event->string[0]=='\t')) {
+				&& ((guchar)event->string[0]>=' ' || event->string[0]=='\t')
+				&& (event->state&(GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+										|GDK_MOD4_MASK|GDK_MOD5_MASK))==0) {
 			DOING *d;
 			GdkPoint select;
 
@@ -1183,8 +1185,20 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	for (i=g_list_length(glist)-1;i>=0;i--) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
-		if (ptw->syscol)
+		if (ptw->syscol) {
 			gtk_widget_draw(ptw->drawing,NULL);
+#ifdef USE_XIM
+			if (gdk_im_ready() && ptw->ic!=NULL
+				&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
+				gdk_ic_get_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FOREGROUND
+												| GDK_IC_PREEDIT_BACKGROUND);
+				ptw->ic_attr->preedit_foreground=system_color[0];
+				ptw->ic_attr->preedit_background=system_color[1];
+				gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FOREGROUND
+												| GDK_IC_PREEDIT_BACKGROUND);
+			}
+#endif
+		}
 	}
 	g_list_free(glist);
 }
@@ -1289,12 +1303,16 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 				str[length]='\0';
 			}
 		}
-	} else {
+	} else if (data->selection==clipboard_atom) {
 		/* åץܡ */
 		if (clipboard_text!=NULL) {
 			str=clipboard_text;
 			length=strlen(clipboard_text);
 		}
+	} else if (data->selection==textmaid_atom) {
+		/* ץ̿ */
+		str="Text maid Selection";
+		length=strlen(str);
 	}
 	if (str!=NULL) {
 		if (info==TARGET_STRING) {
@@ -1311,7 +1329,7 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 			gtk_selection_data_set(data,encoding,format,text,new_length);
 			gdk_free_compound_text(text);
 		}
-		if (str!=clipboard_text)
+		if (data->selection==GDK_SELECTION_PRIMARY)
 			g_free(str);
 	}
 }
@@ -1327,53 +1345,113 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	GdkAtom *atoms;
 	GdkPoint select;
 
-	if (data->length>=0) {
-		if (data->type==GDK_SELECTION_TYPE_ATOM) {
-			/* äȥ */
-			atoms=(GdkAtom *)data->data;
-			count=data->length/sizeof(GdkAtom);
-			for (i=0;i<count;i++)
-				if (atoms[i]==GDK_TARGET_STRING
+	if (data->selection==clipboard_atom) {
+		/* åץܡ */
+		if (data->length>=0) {
+			if (data->type==GDK_SELECTION_TYPE_ATOM) {
+				atoms=(GdkAtom *)data->data;
+				count=data->length/sizeof(GdkAtom);
+				for (i=0;i<count;i++)
+					if (atoms[i]==GDK_TARGET_STRING
 							|| atoms[i]==gdk_atom_intern("COMPOUND_TEXT",FALSE)
 							|| atoms[i]==gdk_atom_intern("TEXT",FALSE))
-					break;
-			if (i<count)
-				gtk_selection_convert(window,clipboard_atom,atoms[i],
+						break;
+				if (i<count)
+					gtk_selection_convert(window,clipboard_atom,atoms[i],
 															GDK_CURRENT_TIME);
-		} else if (data->type==GDK_TARGET_STRING) {
-			data->data[data->length]='\0';
-			text=g_strdup(data->data);
-		} else if (data->type==gdk_atom_intern("COMPOUND_TEXT",FALSE)
+			} else if (data->type==GDK_TARGET_STRING) {
+				data->data[data->length]='\0';
+				text=g_strdup(data->data);
+			} else if (data->type==gdk_atom_intern("COMPOUND_TEXT",FALSE)
 								|| data->type==gdk_atom_intern("TEXT",FALSE)) {
-			count=gdk_text_property_to_text_list(data->type,data->format,
+				count=gdk_text_property_to_text_list(data->type,data->format,
 												data->data,data->length,&list);
-			if (count>0) {
-				text=g_strdup(list[0]);
-				for (i=1;i<count;i++) {
-					str=g_strconcat(text,list[i],NULL);
-					g_free(text);
-					text=str;
+				if (count>0) {
+					text=g_strdup(list[0]);
+					for (i=1;i<count;i++) {
+						str=g_strconcat(text,list[i],NULL);
+						g_free(text);
+						text=str;
+					}
+					gdk_free_text_list(list);
 				}
-				gdk_free_text_list(list);
 			}
 		}
-	}
-	if (text!=NULL) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
+		if (text!=NULL) {
+			ptw=gtk_object_get_user_data(GTK_OBJECT(
+					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-		select=ptw->select;
-		d=edit_operation(ptw,text,strlen(text),TRUE,FALSE);
-		d->next=ptw->undo;
-		ptw->undo=d;
-		if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
-			set_menu_bar(ptw);
-		ptw->edit=TRUE;
-		g_free(text);
+			select=ptw->select;
+			d=edit_operation(ptw,text,strlen(text),TRUE,FALSE);
+			d->next=ptw->undo;
+			ptw->undo=d;
+			if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
+				set_menu_bar(ptw);
+			ptw->edit=TRUE;
+			g_free(text);
+		}
+	} else if (data->selection==textmaid_atom) {
+		/* ץ̿ */
+		instance=MAX(data->length,0);
 	}
 }
 
 
+gboolean signal_client_event(GtkWidget *widget,GdkEventClient *event,
+															gpointer user_data)
+{
+	gint i;
+	COMM *p;
+	TEXTWND *ptw;
+
+	if (event->message_type==textmaid_atom) {
+		for (p=comm;p!=NULL;p=p->next)
+			if (p->pid==event->data.l[4])
+				break;
+		if (p==NULL) {
+			p=g_malloc(sizeof(COMM));
+			p->str=NULL;
+			p->leng=0;
+			p->init_line=0;
+			p->pid=event->data.l[4];
+			p->prev=NULL;
+			p->next=comm;
+			if (p->next!=NULL) {
+				p->next->prev=p;
+			}
+			comm=p;
+		}
+		switch (event->data_format) {
+			case 8:
+				p->str=g_realloc(p->str,p->leng+16);
+				memcpy(p->str+p->leng,event->data.b,16);
+				p->leng+=16;
+				for (i=0;i<16;i++)
+					if (event->data.b[i]=='\0')
+						break;
+				if (i<16) {
+					ptw=open_edit_file(p->str);
+					if (p->init_line!=0)	/* Ԥ˰ư */
+						jump_operation(ptw,p->init_line);
+					g_free(p->str);
+					if (p->prev!=NULL)
+						p->prev->next=p->next;
+					if (p->next!=NULL)
+						p->next->prev=p->prev;
+					if (comm==p)
+						comm=comm->next;
+					g_free(p);
+				}
+				break;
+			case 32:
+				p->init_line=event->data.l[0];
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
+
 gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data)
 {
 	gint page;
