@@ -19,6 +19,7 @@
 #include <ctype.h>
 #include <locale.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include "tmaid.h"
 #include "command.h"
 #include "conf.h"
@@ -39,15 +40,19 @@ gboolean caret=FALSE;				/* åȤη */
 gboolean ins=TRUE;					/* TRUE:,FALSE: */
 gboolean has_selection=FALSE;		/* TRUE:ͭ,FALSE:ʤ */
 gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
+gboolean second=FALSE;				/* TRUE:,FALSE:¸ */
 gchar *hisfile[10];					/* ե */
 gchar *clipboard_text=NULL;			/* åץܡɤΥƥ */
 gint def_width,def_height;			/* ǥեȤΥɥΥ */
 gint ftnum=0;						/* ե륿פο */
 gint history=4;						/* ե */
+gint instance=-1;					/* ץ̿ѿ */
 gint tcount=0;						/* ե륿פΥ */
 guint timer_id=0;					/* ID */
+COMM *comm=NULL;					/* ץ̿ѹ¤ */
 FTYPE *ftype=NULL;					/* ե륿 */
 GdkAtom clipboard_atom;				/* åץܡ */
+GdkAtom textmaid_atom;				/* ץ̿ѥȥ */
 GtkWidget *window;					/* ɥ */
 GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
@@ -72,13 +77,15 @@ int main(int argc,char *argv[])
 	gchar *arg,*endptr,*str,*section=NULL,*key=NULL;
 	gint i,j,k,l,m,opt,leng;
 	gint init_line=0;					/* ΥåȰ */
+	COMM *p;
 	PROFILE *profile;
 	TEXTWND *ptw;
+	GdkEventClient event;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
 	GtkStyle *style;
-	GtkWidget *text,*menubar,*toolbar,*sub_menu,*menu_item,*vbox;
+	GtkWidget *menubar,*toolbar,*text,*handle,*vbox,*sub_menu,*menu_item;
 	GtkItemFactoryEntry menu_items[]={
 {N_("/ե(_F)"),                               NULL,         NULL,            0,"<Branch>"},
 {N_("/ե(F)/(_N)"),                   "<control>N", command_new,     0,"<Item>"},
@@ -146,6 +153,7 @@ int main(int argc,char *argv[])
 	{"line",   'l',"NUM",         N_("ΥåȰ")},
 	{"new",    'n',"ON/OFF",      N_("ե򳫤")},
 	{"size",   's',"WIDTH,HEIGHT",N_("ɥΥ")},
+	{"second", 'x',"ON/OFF",      N_("ɥ򳫤")},
 	{"version",'v',NULL,          N_("С")},
 	{"help",   '?',NULL,          N_("إ")},
 	{NULL,     0,  NULL,          NULL}};
@@ -171,6 +179,9 @@ int main(int argc,char *argv[])
 		if (!profile_get_value(profile,"tmaid","newfile",
 				(gpointer)&newfile,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL))
 			newfile=FALSE;
+		if (!profile_get_value(profile,"tmaid","second",
+				(gpointer)&second,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL))
+			second=FALSE;
 		if (!profile_get_value(profile,"tmaid","def_width",
 				(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			def_width=gdk_screen_width()*2/3;
@@ -366,6 +377,7 @@ int main(int argc,char *argv[])
 						break;
 					case 'n':
 						newfile=g_strcasecmp(arg,"OK")==0
+												|| g_strcasecmp(arg,"ON")==0
 												|| g_strcasecmp(arg,"TRUE")==0
 												|| g_strcasecmp(arg,"YES")==0;
 						break;
@@ -373,6 +385,12 @@ int main(int argc,char *argv[])
 						def_height=strtol(arg,&endptr,0);
 						def_width=strtol(++endptr,&endptr,0);
 						break;
+					case 'x':
+						second=g_strcasecmp(arg,"OK")==0
+												|| g_strcasecmp(arg,"ON")==0
+												|| g_strcasecmp(arg,"TRUE")==0
+												|| g_strcasecmp(arg,"YES")==0;
+						break;
 					case 'v':
 						g_print(
 "Text maid "VERSION"\n"
@@ -443,35 +461,24 @@ int main(int argc,char *argv[])
 										GTK_SIGNAL_FUNC(signal_delete),NULL);
 	gtk_signal_connect(GTK_OBJECT(window),"destroy",
 												signal_destroy_window,NULL);
-	gtk_widget_show(window);
-	/* ƥ */
-	text=gtk_text_new(NULL,NULL);
-	gtk_widget_set_parent(text,window);
-	gtk_widget_realize(text);
-	gtk_signal_connect(GTK_OBJECT(text),"style-set",signal_style_set,NULL);
-	style=gtk_widget_get_style(text);
-	system_color[ 0]=style->text[0];
-	system_color[ 1]=style->base[0];
-	system_color[ 2]=style->dark[0];
-	system_color[ 3]=style->dark[0];
-	system_color[ 4]=style->dark[0];
-	system_color[ 5]=style->dark[0];
-	system_color[ 6]=style->dark[0];
-	system_color[ 7]=style->mid[0];
-	system_color[ 8]=style->fg[3];
-	system_color[ 9]=style->bg[3];
+	gtk_widget_realize(window);
 	/* Drag and Drop */
 	gtk_drag_dest_set(window,GTK_DEST_DEFAULT_MOTION
 						| GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
 												drag_types,1,GDK_ACTION_COPY);
 	gtk_signal_connect(GTK_OBJECT(window),"drag_data_received",
 						    GTK_SIGNAL_FUNC(signal_drag_data_received),NULL);
-	/* åץܡ */
+	/* åץܡ/ץ̿ */
 	clipboard_atom=gdk_atom_intern("CLIPBOARD",FALSE);
+	textmaid_atom=gdk_atom_intern("Text maid InterProcess communication",
+																		FALSE);
 	gtk_selection_add_targets(window,GDK_SELECTION_PRIMARY,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	gtk_selection_add_targets(window,clipboard_atom,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
+	if (!second)
+		gtk_selection_add_targets(window,textmaid_atom,
+							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	gtk_signal_connect(GTK_OBJECT(window),"selection-clear-event",
 								GTK_SIGNAL_FUNC(signal_selection_clear),NULL);
 	gtk_signal_connect(GTK_OBJECT(window),"selection-get",
@@ -487,7 +494,8 @@ int main(int argc,char *argv[])
 								GTK_SIGNAL_FUNC(signal_destroy_notebook),NULL);
 	/* ݥåץå */
 	accel_group=gtk_accel_group_new();
-	item_factory_popup=gtk_item_factory_new(GTK_TYPE_MENU,"<main>",accel_group);
+	item_factory_popup=gtk_item_factory_new(GTK_TYPE_MENU,
+														"<main>",accel_group);
 	gtk_item_factory_create_items(item_factory_popup,
 			sizeof(popup_items)/sizeof(GtkItemFactoryEntry),popup_items,NULL);
 	/* ˥塼 */
@@ -513,13 +521,23 @@ int main(int argc,char *argv[])
 		}
 	/* ơС */
 	status=gtk_statusbar_new();
-	/* ľܥå */
+	/* ƥ */
+	text=gtk_text_new(NULL,NULL);
+	gtk_signal_connect(GTK_OBJECT(text),"style-set",signal_style_set,NULL);
+	/* ľܥå/ϥɥܥå */
 	vbox=gtk_vbox_new(FALSE,0);
-	gtk_container_add(GTK_CONTAINER(window),vbox);
-	gtk_box_pack_start(GTK_BOX(vbox),menubar,FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),toolbar,FALSE,FALSE,0);
+	handle=gtk_handle_box_new();
+	gtk_container_set_border_width (GTK_CONTAINER(handle),2);
+	gtk_container_add(GTK_CONTAINER(handle),menubar);
+	gtk_box_pack_start(GTK_BOX(vbox),handle,FALSE,FALSE,0);
+	handle=gtk_handle_box_new();
+	gtk_container_set_border_width (GTK_CONTAINER(handle),2);
+	gtk_container_add(GTK_CONTAINER(handle),toolbar);
+	gtk_box_pack_start(GTK_BOX(vbox),handle,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),notebook,TRUE,TRUE,0);
 	gtk_box_pack_end(GTK_BOX(vbox),status,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
 													_("<main>/ե(F)"));
@@ -540,10 +558,61 @@ int main(int argc,char *argv[])
 	/* ˥塼ɽ */
 	set_menu_bar(NULL);
 
+	/* ˵ưƤ뤫å */
+	if (!second) {
+		gtk_selection_convert(window,textmaid_atom,
+								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
+		while (instance<0)
+			while (gtk_events_pending())
+				gtk_main_iteration();
+		if (instance>0) {
+			/* ˵ưƤȤ */
+			event.type=GDK_CLIENT_EVENT;
+			event.window=window->window;
+			event.send_event=TRUE;
+			event.message_type=textmaid_atom;
+			event.data_format=32;
+			event.data.l[0]=init_line;
+			event.data.l[4]=getpid();
+			gdk_event_send_clientmessage_toall((GdkEvent *)&event);
+			event.data_format=8;
+			for (i=1;i<argc;i++)
+				if (arg_files[i]) {
+					str=get_full_path(argv[i]);
+					g_print("%s\n",str);
+					leng=strlen(str)+1;
+					for (j=0;j<leng;j+=16) {
+						memcpy(event.data.b,str+j,MIN(leng-j,16));
+						gdk_event_send_clientmessage_toall((GdkEvent *)&event);
+					}
+					g_free(str);
+				}
+			g_free(arg_files);
+			gtk_exit(0);
+		}
+		gtk_signal_connect(GTK_OBJECT(window),"client-event",
+									GTK_SIGNAL_FUNC(signal_client_event),NULL);
+		gtk_selection_owner_set(window,textmaid_atom,GDK_CURRENT_TIME);
+	}
+
 	/* ɽ */
 	gtk_widget_show_all(window);
+	gtk_widget_hide_all(text);
 	gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
 
+	/* ƥ࿧ */
+	style=gtk_widget_get_style(text);
+	system_color[ 0]=style->text[0];
+	system_color[ 1]=style->base[0];
+	system_color[ 2]=style->dark[0];
+	system_color[ 3]=style->dark[0];
+	system_color[ 4]=style->dark[0];
+	system_color[ 5]=style->dark[0];
+	system_color[ 6]=style->dark[0];
+	system_color[ 7]=style->mid[0];
+	system_color[ 8]=style->fg[3];
+	system_color[ 9]=style->bg[3];
+
 	/* ɥ */
 	for (i=1;i<argc;i++)
 		if (arg_files[i]) {
@@ -566,6 +635,8 @@ int main(int argc,char *argv[])
 				(gpointer)&history,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","newfile",
 				(gpointer)&newfile,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL);
+		profile_set_value(profile,"tmaid","second",
+				(gpointer)&second,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","def_width",
 				(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","def_height",
@@ -709,6 +780,11 @@ int main(int argc,char *argv[])
 	}
 	g_free(ftype);
 	g_free(clipboard_text);
-
+	while (comm!=NULL) {
+		g_free(comm->str);
+		p=comm->next;
+		g_free(comm);
+		comm=p;
+	}
 	return 0;
 }
