@@ -30,7 +30,6 @@
 
 
 #define MENUFILE 10
-#define iskanji(ch) (((ch)&0x80)!=0)
 
 
 typedef struct ftype {
@@ -107,6 +106,12 @@ typedef struct textwnd {
 	GtkWidget *vscroll;			/* ľС */
 	GtkWidget *menu_item;		/* ˥塼Υɥι */
 } TEXTWND;
+typedef struct comm {
+	gchar *str;
+	gint leng,init_line;
+	gint32 pid;
+	struct comm *prev,*next;
+} COMM;
 
 
 enum {
@@ -120,15 +125,19 @@ extern gboolean caret;					/* åȤη */
 extern gboolean ins;					/* TRUE:,FALSE: */
 extern gboolean has_selection;			/* TRUE:ͭ,FALSE:ʤ */
 extern gboolean newfile;				/* TRUE:ե,FALSE:ʤ */
+extern gboolean second;					/* TRUE:,FALSE:¸ */
 extern gchar *clipboard_text;			/* åץܡɤΥƥ */
 extern gchar *hisfile[10];				/* ե */
 extern gint def_width,def_height;		/* ǥեȤΥɥΥ */
 extern gint ftnum;						/* ե륿פο */
 extern gint history;					/* ե */
+extern gint instance;					/* ץ̿ѿ */
 extern gint tcount;						/* ե륿פΥ */
 extern guint timer_id;					/* ID */
+extern COMM *comm;						/* ץ̿ѹ¤ */
 extern FTYPE *ftype;					/* ե륿 */
 extern GdkAtom clipboard_atom;			/* åץܡ */
+extern GdkAtom textmaid_atom;			/* ץ̿ѥȥ */
 extern GtkWidget *window;				/* ɥ */
 extern GtkWidget *notebook;				/* Ρȥ֥å */
 extern GtkWidget *status;				/* ơɥ */
