@@ -94,6 +94,7 @@ gboolean valchr_dialog(gchar *valchr)
 {
 	gchar *text;
 	GSList *group=NULL;
+	GtkAccelGroup *accel;
 	GtkWidget *button1,*radio0,*radio1,*radio2,*frame,*hbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
@@ -118,22 +119,37 @@ gboolean valchr_dialog(gchar *valchr)
 												valchr_dialog_activate,valchr);
 	gtk_signal_connect(GTK_OBJECT(entry),"changed",valchr_dialog_changed,NULL);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(group,_("8ʿ"));
+	radio0=gtk_radio_button_new_with_label(group,_("16ʿ"));
 	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio0));
 	radio1=gtk_radio_button_new_with_label(group,_("10ʿ"));
 	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio1));
-	radio2=gtk_radio_button_new_with_label(group,_("16ʿ"));
+	radio2=gtk_radio_button_new_with_label(group,_("8ʿ"));
 	switch (valchr_base) {
-	case  8:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio0),TRUE);break;
+	case 16:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio0),TRUE);break;
 	case 10:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1),TRUE);break;
-	case 16:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio2),TRUE);
+	case  8:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio2),TRUE);
 	}
 	gtk_signal_connect(GTK_OBJECT(radio0),"clicked",
-									valchr_dialog_clicked_radio,(gpointer)8);
+									valchr_dialog_clicked_radio,(gpointer)16);
 	gtk_signal_connect(GTK_OBJECT(radio1),"clicked",
 									valchr_dialog_clicked_radio,(gpointer)10);
 	gtk_signal_connect(GTK_OBJECT(radio2),"clicked",
-									valchr_dialog_clicked_radio,(gpointer)16);
+									valchr_dialog_clicked_radio,(gpointer)8);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_widget_add_accelerator(radio0,"clicked",accel,'H',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(radio0)->child,'H');
+	gtk_widget_add_accelerator(radio1,"clicked",accel,'T',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(radio1)->child,'T');
+	gtk_widget_add_accelerator(radio2,"clicked",accel,'Q',
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	set_label_pattern(GTK_BIN(radio2)->child,'Q');
 	/* ե졼ȥܥå */
 	frame=gtk_frame_new(_(""));
 	vbox=gtk_vbox_new(FALSE,0);
